@@ -11,7 +11,9 @@ our @ISA = qw(SelectPdf::ApiClient);
 SelectPdf::HtmlToPdfClient - Html To Pdf Conversion with SelectPdf Online API.
 
 =head1 SYNOPSIS
- 
+
+Convert URL to PDF and save result into a file on disk.
+
     use SelectPdf;
     print "This is SelectPdf-$SelectPdf::VERSION\n";
 
@@ -21,7 +23,7 @@ SelectPdf::HtmlToPdfClient - Html To Pdf Conversion with SelectPdf Online API.
 
     eval {
         my $client = new HtmlToPdfClient($apiKey);
-        
+
         $client
             ->setPageSize("A4")
             ->setMargins(0)
@@ -36,6 +38,34 @@ SelectPdf::HtmlToPdfClient - Html To Pdf Conversion with SelectPdf Online API.
         print "An error occurred: $@\n";  
     }
 
+Convert raw HTML string to PDF and save result into a file on disk.
+
+    use SelectPdf;
+    print "This is SelectPdf-$SelectPdf::VERSION\n";
+
+    my $html = "This is a <b>test HTML</b>.";
+    my $local_file = "Test.pdf";
+    my $apiKey = "Your API key here";
+
+    eval {
+        my $client = new HtmlToPdfClient($apiKey);
+
+        $client
+            ->setPageSize("A4")
+            ->setMargins(0)
+            ->setShowPageNumbers('False')
+            ->setPageBreaksEnhancedAlgorithm('True')
+        ;
+
+        $client->convertHtmlStringToFile($html, $local_file);
+    };
+
+    if ($@) {
+        print "An error occurred: $@\n";  
+    }
+
+For more details and full list of parameters see L<Html To Pdf API|https://selectpdf.com/html-to-pdf-api/>.
+
 =head1 METHODS
 
 =head2 new( $apiKey )
